<?php namespace WP_CLI_Dotenv_Command;

use WP_CLI;

/**
 * Class Salts
 * @package WP_CLI_Dotenv_Command
 */
class Salts
{
    /**
     * WordPress.org Salt Generator Service URL
     */
    const GENERATOR_URL = 'https://api.wordpress.org/secret-key/1.1/salt/';

    /**
     * Pattern to match both key and value
     */
    const PATTERN_CAPTURE = '#\'([^\']+)\'#';

    /**
     * @return array|void
     */
    public static function fetch_array()
    {
        // read in each line as an array
        $response = file( static::GENERATOR_URL );

        if ( ! is_array( $response ) ) {
            WP_CLI::error('There was a problem fetching salts from the WordPress generator service.');
            return;
        }

        return (array) static::parse_php_to_array( $response );
    }

    /**
     * Parse the php generated by the WordPress.org salts generator to an array of key => value pairs
     *
     * @param $response
     *
     * @return array
     */
    public static function parse_php_to_array( array $response )
    {
        $salts = [ ];

        foreach ( $response as $line )
        {
            // capture everything between single quotes
            preg_match_all( self::PATTERN_CAPTURE, $line, $matches );

            // 0 - complete match
            // 1 - captures
            if ( ! isset( $matches[ 1 ] ) ) {
                continue;
            }

            $captures = $matches[ 1 ];

            $constant_name  = array_shift( $captures );
            $constant_value = array_shift( $captures );

            if ( $constant_name ) {
                $salts[ $constant_name ] = $constant_value;
            }

            unset( $matches );
        }

        return $salts;
    }
}